# Table of Contents

- [meta-model-ai-governance-extension](<./meta-model-ai-governance-extension.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [AI Governance Extension to the Meta Model](<./AI-Governance-Extension-to-the-Meta-Model.md>)
  - [Overview](<./AI-Governance-Extension-to-the-Meta-Model/Overview.md>)
  - [Activating the Extension](<./AI-Governance-Extension-to-the-Meta-Model/Activating-the-Extension.md>)
  - [Meta Model Additions](<./AI-Governance-Extension-to-the-Meta-Model/Meta-Model-Additions.md>)
  - [Getting Insights from Reports](<./AI-Governance-Extension-to-the-Meta-Model/Getting-Insights-from-Reports.md>)
  - [Was this page helpful?](<./AI-Governance-Extension-to-the-Meta-Model/Was-this-page-helpful.md>)
